#include <math.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "settings.h"

Settings settings;

void loadsettings()
{
	//Values for nonconfigurable settings
	settings.launchdist	= 20;
	settings.basesize	= 10;
	settings.randsize	= 10;
	
	//Defaults for configurable settings
	settings.numcells	= 50;
	settings.numbees	= 173;
	settings.vectors	= false;
	settings.eventms	= 100;
	settings.hiquality	= true;

	FILE* f = fopen( "Hive.cfg", "r" );
	if ( !f )
	{
		return;
	}
	char c[64];
	while ( fgets( c, 64, f ) )
	{
		     if ( !memcmp( c, "numcells=", 9 ) )
			settings.numcells = atoi( c+9 );
		else if ( !memcmp( c, "numbees=", 8 ) )
			settings.numbees = atoi( c+8 );
		else if ( !memcmp( c, "vectors=T", 9 ) )
			settings.vectors = true;
		else if ( !memcmp( c, "vectors=F", 9 ) )
			settings.vectors = false;
		else if ( !memcmp( c, "eventms=", 8 ) )
			settings.eventms = atoi( c+8 );
		else if ( !memcmp( c, "hiquality=T", 11 ) )
			settings.hiquality = true;
		else if ( !memcmp( c, "hiquality=F", 11 ) )
			settings.hiquality = false;
	}

	fclose( f );

	//Sanity checks
	if ( settings.numcells < 2 ) settings.numcells = 2;
	if ( settings.numbees < 0 ) settings.numbees = 0;
	if ( settings.eventms < 1 ) settings.eventms = 1;
}

void savesettings()
{
	FILE* f = fopen( "Hive.cfg", "w" );
	if ( !f ) return;

	fprintf( f, "#\n#\n# HIVE SCREENSAVER SETTINGS\n#\n" );

	fprintf( f, "# Number of cells\n" );
	fprintf( f, "numcells=%d\n", settings.numcells );

	fprintf( f, "# Number of bees\n" );
	fprintf( f, "numbees=%d\n", settings.numbees );

	fprintf( f, "# Debug vectors visible\n" );
	fprintf( f, "vectors=%c\n", settings.vectors ? 'T' : 'F' );

	fprintf( f, "# Milliseconds between bee swap events\n" );
	fprintf( f, "eventms=%d\n", settings.eventms );

	fprintf( f, "# High graphical quality\n" );
	fprintf( f, "hiquality=%c\n", settings.hiquality ? 'T' : 'F' );

	fclose( f );
}
